@@ -74,3 +74,7 @@ val replace : t -> int -> int -> t -> t
   (** [replace set offset length repl] replaces the subset at offset
       [offset] and length [length] by [repl] in [set]. *)
 
+val get_idx_by_width : t -> int -> int -> int
+  (** [get_idx_by_width set row column_width] return the offset of the char
+      at \[row, column_width\]. *)
+
